<?xml version="1.0" ?>
<!-- 
***************************************************************************
Copyright (C) 2005 egrath 
***************************************************************************
-->
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:rss="http://purl.org/rss/1.0/"
	xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" 
	xmlns:dc="http://purl.org/dc/elements/1.1/" 
	xmlns:qlex="uuid:BB773031-B026-4064-9B42-6715E2A4AC7F" 
	exclude-result-prefixes="rss rdf dc qlex">
<xsl:output method="html" encoding="UTF-8" />

<!-- 
***************************************************************************
root 
***************************************************************************
-->
<xsl:template match="/">
	<xsl:choose>
		<!-- RSS 0.91 2.0 -->
		<xsl:when test='count(/rss)>0'>
			<xsl:apply-templates select="/rss/channel"/>
		</xsl:when>
		<!-- RSS 1.0 -->
		<xsl:when test='count(/rdf:RDF)>0'>
			<xsl:apply-templates select="/rdf:RDF"/>
		</xsl:when>
		<!-- site (internet shortcut)-->
		<xsl:when test='count(/qlex:QLinkEx/qlex:site)>0'>
			<xsl:apply-templates select="/qlex:QLinkEx/qlex:site"/>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<!-- 
***************************************************************************
RSS 0.91, 2.0 
***************************************************************************
-->
<xsl:template match="/rss/channel">
	<!-- herader  -->
	<xsl:call-template name="updateNotifyHeaderRSS"/>
	
	<!-- html -->
	<div class="item">
		<xsl:attribute name="id"><xsl:value-of select="qlex:id"/></xsl:attribute>
		<xsl:call-template name="rssTitle">
			<xsl:with-param name="id"><xsl:value-of select="qlex:id"/></xsl:with-param>
			<xsl:with-param name="title">
				<xsl:choose>
					<xsl:when test='count(qlex:name)>0'>
						<xsl:value-of select="qlex:name"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="title"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
			<xsl:with-param name="link"><xsl:value-of select="translate(normalize-space(link), ' ', '')"/></xsl:with-param>
			<xsl:with-param name="itemCount"><xsl:value-of select="count(item)"/></xsl:with-param>
		</xsl:call-template>
		
		<div class="subitems">
			<xsl:for-each select="item">
				<xsl:call-template name="rssItem">
					<xsl:with-param name="id"><xsl:value-of select="qlex:id"/></xsl:with-param>
					<xsl:with-param name="title"><xsl:value-of select="title"/></xsl:with-param>
					<xsl:with-param name="link"><xsl:value-of select="translate(normalize-space(link), ' ', '')"/></xsl:with-param>
					<xsl:with-param name="description"><xsl:value-of select="description"/></xsl:with-param>
					<xsl:with-param name="creator"><xsl:value-of select="dc:creator"/></xsl:with-param>
					<xsl:with-param name="date">
						<xsl:choose>
							<xsl:when test='count(qlex:date)>0'>
								<xsl:value-of select="qlex:date"/>
							</xsl:when>
							<xsl:when test="count(pubDate)>0">
								<xsl:value-of select="pubDate"/>
							</xsl:when>
							<xsl:when test="count(dc:date)>0">
								<xsl:value-of select="dc:date"/>
							</xsl:when>
						</xsl:choose>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:for-each>
		</div>
	</div>
</xsl:template>

<!-- 
***************************************************************************
RSS 1.0 
***************************************************************************
-->
<xsl:template match="/rdf:RDF">
	<!-- herader -->
	<xsl:call-template name="updateNotifyHeaderRDF"/>
	
	<!-- html(html format) -->
	<div class="item">
		<xsl:attribute name="id"><xsl:value-of select="rss:channel/qlex:id"/></xsl:attribute>
		<xsl:call-template name="rssTitle">
			<xsl:with-param name="id"><xsl:value-of select="rss:channel/qlex:id"/></xsl:with-param>
			<xsl:with-param name="title">
				<xsl:choose>
					<xsl:when test='count(rss:channel/qlex:name)>0'>
						<xsl:value-of select="rss:channel/qlex:name"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="rss:channel/rss:title"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
			<xsl:with-param name="link"><xsl:value-of select="translate(normalize-space(rss:channel/rss:link), ' ', '')"/></xsl:with-param>
			<xsl:with-param name="itemCount"><xsl:value-of select="count(rss:item)"/></xsl:with-param>
		</xsl:call-template>
		
		<div class="subitems">
			<xsl:for-each select="rss:item">
				<xsl:call-template name="rssItem">
					<xsl:with-param name="id"><xsl:value-of select="qlex:id"/></xsl:with-param>
					<xsl:with-param name="title"><xsl:value-of select="rss:title"/></xsl:with-param>
					<xsl:with-param name="link"><xsl:value-of select="translate(normalize-space(rss:link), ' ', '')"/></xsl:with-param>
					<xsl:with-param name="description"><xsl:value-of select="rss:description"/></xsl:with-param>
					<xsl:with-param name="creator"><xsl:value-of select="dc:creator"/></xsl:with-param>
					<xsl:with-param name="date">
						<xsl:choose>
							<xsl:when test='count(qlex:date)>0'>
								<xsl:value-of select="qlex:date"/>
							</xsl:when>
							<xsl:when test="count(pubDate)>0">
								<xsl:value-of select="pubDate"/>
							</xsl:when>
							<xsl:when test="count(dc:date)>0">
								<xsl:value-of select="dc:date"/>
							</xsl:when>
						</xsl:choose>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:for-each>
		</div>
	</div>
</xsl:template>

<!-- 
***************************************************************************
site (internet shortcut)
***************************************************************************
-->
<xsl:template match="/qlex:QLinkEx/qlex:site">
	<!-- herader -->
	<xsl:call-template name="updateNotifyHeaderSite"/>
	
	<!-- html(html format) -->
	<div class="item">
		<xsl:attribute name="id"><xsl:value-of select="qlex:id"/></xsl:attribute>
		<div class="site_title">
			<xsl:call-template name="readedButton">
				<xsl:with-param name="id"><xsl:value-of select="qlex:id"/></xsl:with-param>
				<xsl:with-param name="class">margin_right</xsl:with-param>
				<xsl:with-param name="type">2</xsl:with-param>
			</xsl:call-template>
			<a class="site_title_text">	
				<xsl:attribute name="onclick">openCompatible('<xsl:value-of select="qlex:link"/>');cancelEvent(event);setReaded('<xsl:value-of select="qlex:id"/>', true);</xsl:attribute>
				<xsl:attribute name="href"><xsl:value-of select="qlex:link"/></xsl:attribute>
				<xsl:attribute name="target">_blank</xsl:attribute>
				<xsl:attribute name="title">
					<xsl:value-of select="qlex:title"/>
					<xsl:text>&#13;&#10;</xsl:text>
					<xsl:value-of select="qlex:link"/>
				</xsl:attribute>
				<xsl:value-of select="qlex:title"/>
			</a>
		</div>
	</div>
</xsl:template>

<!-- 
***************************************************************************
output header for RSS 0.91 2.0
item table(xml format)
***************************************************************************
-->
<xsl:template name="updateNotifyHeaderRSS">
	<item_table version="1.0">
		<item>
			<xsl:attribute name="id"><xsl:value-of select="qlex:id"/></xsl:attribute>
			<url setReaded="0"><xsl:value-of select="translate(normalize-space(link), ' ', '')"/></url>
		<xsl:for-each select="item">
			<item>
				<xsl:attribute name="id"><xsl:value-of select="qlex:id"/></xsl:attribute>
				<url><xsl:value-of select="translate(normalize-space(link), ' ', '')"/></url>
			</item>
		</xsl:for-each>
		</item>
	</item_table>
</xsl:template>

<!-- 
***************************************************************************
output header for RSS 1.0
item table(xml format)
***************************************************************************
-->
<xsl:template name="updateNotifyHeaderRDF">
	<item_table version="1.0">
		<item>
			<xsl:attribute name="id"><xsl:value-of select="rss:channel/qlex:id"/></xsl:attribute>
			<url setReaded="0"><xsl:value-of select="translate(normalize-space(rss:channel/rss:link), ' ', '')"/></url>
		<xsl:for-each select="rss:item">
			<item>
				<xsl:attribute name="id"><xsl:value-of select="qlex:id"/></xsl:attribute>
				<url><xsl:value-of select="translate(normalize-space(rss:link), ' ', '')"/></url>
				<url><xsl:value-of select="translate(normalize-space(@rdf:about), ' ', '')"/></url>
			</item>
		</xsl:for-each>
		</item>
	</item_table>
</xsl:template>

<!-- 
***************************************************************************
output header for site
item table(xml format)
***************************************************************************
-->
<xsl:template name="updateNotifyHeaderSite">
	<item_table version="1.0">
		<item>
			<xsl:attribute name="id"><xsl:value-of select="qlex:id"/></xsl:attribute>
			<url><xsl:value-of select="qlex:link"/></url>
		</item>
	</item_table>
</xsl:template>

<!-- 
***************************************************************************
output RSS title
***************************************************************************
-->
<xsl:template name="rssTitle">
	<xsl:param name="id"></xsl:param>
	<xsl:param name="title"></xsl:param>
	<xsl:param name="link">javascript:void(0)</xsl:param>
	<xsl:param name="itemCount">-1</xsl:param>
	
	<div class="item_title">
		<xsl:call-template name="readedButton">
			<xsl:with-param name="class">margin_right</xsl:with-param>
			<xsl:with-param name="type">0</xsl:with-param>
			<xsl:with-param name="id"><xsl:value-of select="$id"/></xsl:with-param>
		</xsl:call-template>
		<a class="item_title_text">
			<xsl:attribute name="onclick">cancelEvent(event);</xsl:attribute>
			<xsl:attribute name="ondblclick">cancelEvent(event);toggleSubitems('<xsl:value-of select="$id"/>');</xsl:attribute>
			<xsl:attribute name="href"><xsl:value-of select="$link"/></xsl:attribute>
			<xsl:attribute name="target">_blank</xsl:attribute>
			<xsl:attribute name="title">
				<xsl:value-of select="$title"/>
				<xsl:text>&#13;&#10;</xsl:text>
				<xsl:value-of select="$link"/>
			</xsl:attribute>
			<xsl:value-of disable-output-escaping="yes" select="$title"/>
		</a>
		<xsl:if test="$itemCount>0">
			<span class="itemCount">
				(<xsl:value-of select="$itemCount"/>件の未読)
			</span>
		</xsl:if>
	</div>
</xsl:template>

<!-- 
***************************************************************************
output RSS item
***************************************************************************
-->
<xsl:template name="rssItem">
	<xsl:param name="id"></xsl:param>
	<xsl:param name="title"></xsl:param>
	<xsl:param name="link"></xsl:param>
	<xsl:param name="description"></xsl:param>
	<xsl:param name="creator"></xsl:param>
	<xsl:param name="date"></xsl:param>
	
	<span class="subitem" id="{$id}">
		<span class="subitem_title">
			<xsl:call-template name="readedButton">
				<xsl:with-param name="class">margin_right</xsl:with-param>
				<xsl:with-param name="type">1</xsl:with-param>
				<xsl:with-param name="id"><xsl:value-of select="$id"/></xsl:with-param>
			</xsl:call-template>
			<a class="subitem_title_text">
				<xsl:attribute name="onclick">openCompatible('<xsl:value-of select="$link"/>');cancelEvent(event);setReadedByUrl('<xsl:value-of select="$link"/>');</xsl:attribute>
				<xsl:if test="string-length($link)>0">
					<xsl:attribute name="href"><xsl:value-of select="$link"/></xsl:attribute>
					<xsl:attribute name="target">_blank</xsl:attribute>
				</xsl:if>
				<xsl:attribute name="title">
					<xsl:value-of select="$title"/>
					<xsl:if test="string-length($creator)>0 or string-length($date)>0">
						<xsl:text>(</xsl:text>
						<xsl:value-of select="$creator"/>
						<xsl:if test="string-length($date)>0">
							<xsl:text> </xsl:text>
						</xsl:if>
						<xsl:value-of select="$date"/>	
						<xsl:text>)</xsl:text>
					</xsl:if>
					<xsl:text>&#13;&#10;</xsl:text>
					<xsl:value-of select="$link"/>
				</xsl:attribute>
				<xsl:value-of disable-output-escaping="yes" select="$title"/>
			</a>
		</span>
		
		<xsl:if test="string-length($creator)>0 or string-length($date)>0">
			<span class="subitem_author">
				<xsl:text>(</xsl:text>
				<xsl:value-of select="$creator"/>
				<xsl:if test="string-length($date)>0">
					<xsl:text> </xsl:text>
				</xsl:if>
				<xsl:value-of select="$date"/>	
				<xsl:text>)</xsl:text>
			</span>
		</xsl:if>
		
		<!--
		<xsl:if test="string-length($description)>0">
			<div class="subitem_description">
				<xsl:value-of disable-output-escaping="yes" select="$description"/>
			</div>
		</xsl:if>
		-->
	</span>
</xsl:template>

<!-- 
***************************************************************************
output readed button
***************************************************************************
-->
<xsl:template name="readedButton">
	<xsl:param name="id">0</xsl:param>
	<xsl:param name="type">0</xsl:param>
	
	<img class="img_margin_right">
		<xsl:choose>
			<!-- rss parent -->
			<xsl:when test="$type='0'">
				<xsl:attribute name="src">./readedBtn.gif</xsl:attribute>
				<xsl:attribute name="title">全て既読にする</xsl:attribute>
				<xsl:attribute name="onclick">setReaded('<xsl:value-of select="$id"/>', true);</xsl:attribute>
				<xsl:attribute name="onmousedown">setBtnImage(event.srcElement, true);</xsl:attribute>
				<xsl:attribute name="onmouseout">setBtnImage(event.srcElement, false);</xsl:attribute>
				<xsl:attribute name="onmouseup">setBtnImage(event.srcElement, false);</xsl:attribute>
			</xsl:when>
			<xsl:when test="$type='1'">
				<xsl:attribute name="src">./BtnBlack.gif</xsl:attribute>
				<xsl:attribute name="title">既読にする</xsl:attribute>
				<xsl:attribute name="onclick">setReaded('<xsl:value-of select="$id"/>', false);</xsl:attribute>
				<xsl:attribute name="onmouseover">setBtnBlackImage(event.srcElement, 1);</xsl:attribute>
				<xsl:attribute name="onmousedown">setBtnBlackImage(event.srcElement, 2);</xsl:attribute>
				<xsl:attribute name="onmouseout">setBtnBlackImage(event.srcElement, 3);</xsl:attribute>
				<xsl:attribute name="onmouseup">setBtnBlackImage(event.srcElement, 0);</xsl:attribute>
			</xsl:when>
			<xsl:when test="$type='2'">
				<xsl:attribute name="src">./readedBtn.gif</xsl:attribute>
				<xsl:attribute name="title">訪問済みにする</xsl:attribute>
				<xsl:attribute name="onclick">setReaded('<xsl:value-of select="$id"/>', true);</xsl:attribute>
				<xsl:attribute name="onmousedown">setBtnImage(event.srcElement, true);</xsl:attribute>
				<xsl:attribute name="onmouseout">setBtnImage(event.srcElement, false);</xsl:attribute>
				<xsl:attribute name="onmouseup">setBtnImage(event.srcElement, false);</xsl:attribute>
			</xsl:when>
		</xsl:choose>
	</img>
</xsl:template>

</xsl:stylesheet>